==> react-molecule-autosuggest-2.12.0.tgz: package/lib/components/MultipleSelection.js <==
/* eslint-disable react/prop-types */
import React, { useRef } from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import MoleculeInputTags from '@s-ui/react-molecule-input-tags';
import withClearUI from '../hoc/withClearUI';
var MoleculeInputTagsWithClearUI = withClearUI(MoleculeInputTags);

var MoleculeAutosuggestFieldMultiSelection = function MoleculeAutosuggestFieldMultiSelection(_ref) {
  var id = _ref.id,
      refMoleculeAutosuggest = _ref.refMoleculeAutosuggest,
      tags = _ref.tags,
      value = _ref.value,
      onToggle = _ref.onToggle,
      iconCloseTag = _ref.iconCloseTag,
      isOpen = _ref.isOpen,
      iconClear = _ref.iconClear,
      innerRefInput = _ref.innerRefInput,
      placeholder = _ref.placeholder,
      children = _ref.children,
      onInputKeyDown = _ref.onInputKeyDown,
      onChange = _ref.onChange,
      onChangeTags = _ref.onChangeTags,
      onSelect = _ref.onSelect,
      disabled = _ref.disabled,
      required = _ref.required,
      tabIndex = _ref.tabIndex,
      autoComplete = _ref.autoComplete;
  var MoleculeInputTagsRef = useRef();

  var handleMultiSelection = function handleMultiSelection(ev, _ref2) {
    var value = _ref2.value;
    var newTags = tags.includes(value) ? tags.filter(function (tag) {
      return tag !== value;
    }) : [].concat(tags, [value]);
    onChangeTags(ev, {
      value: '',
      tags: newTags
    });
    onSelect(ev, {
      value: '',
      tags: newTags
    });
    onToggle(ev, {
      isOpen: false
    });
    refMoleculeAutosuggest.current.focus();
  };

  var handleChangeTags = function handleChangeTags(ev, _ref3) {
    var tags = _ref3.tags,
        value = _ref3.value;
    var isOpen = Boolean(value);
    onChangeTags(ev, {
      tags: tags
    });
    onToggle(ev, {
      isOpen: isOpen
    });
    refMoleculeAutosuggest.current.focus();
  };

  var handleChange = function handleChange(ev, _ref4) {
    var value = _ref4.value;
    var isOpen = Boolean(value);
    onChange(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: isOpen
    });
  };

  var handleClear = function handleClear() {
    onChange(null, {
      value: ''
    });
    onChangeTags(null, {
      tags: []
    });
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(MoleculeInputTagsWithClearUI, {
    id: id,
    onKeyDown: onInputKeyDown,
    ref: MoleculeInputTagsRef,
    tags: tags,
    value: value,
    onClick: onToggle,
    tagsCloseIcon: iconCloseTag,
    onChangeTags: handleChangeTags,
    onChange: handleChange,
    isOpen: isOpen,
    isVisibleClear: tags.length,
    iconClear: iconClear,
    onClickClear: handleClear,
    innerRefInput: innerRefInput,
    placeholder: !tags.length ? placeholder : '',
    noBorder: true,
    disabled: disabled,
    required: required,
    tabIndex: tabIndex,
    autoComplete: autoComplete
  }), /*#__PURE__*/React.createElement(MoleculeDropdownList, {
    checkbox: true,
    visible: isOpen,
    onSelect: handleMultiSelection,
    value: tags,
    highlightQuery: value
  }, children));
};

MoleculeAutosuggestFieldMultiSelection.displayName = 'MoleculeAutosuggestFieldMultiSelection';
MoleculeAutosuggestFieldMultiSelection.defaultProps = {
  disabled: false,
  value: '',
  tags: [],
  iconCloseTag: /*#__PURE__*/React.createElement("span", null),
  autoComplete: 'nope'
};
export default MoleculeAutosuggestFieldMultiSelection;

==> react-molecule-autosuggest-2.18.0.tgz: package/lib/components/MultipleSelection.js <==
/* eslint-disable react/prop-types */
import React, { useRef } from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import MoleculeInputTags from '@s-ui/react-molecule-input-tags';
import withClearUI from '../hoc/withClearUI';
var MoleculeInputTagsWithClearUI = withClearUI(MoleculeInputTags);

var MoleculeAutosuggestFieldMultiSelection = function MoleculeAutosuggestFieldMultiSelection(_ref) {
  var id = _ref.id,
      refMoleculeAutosuggest = _ref.refMoleculeAutosuggest,
      tags = _ref.tags,
      value = _ref.value,
      onToggle = _ref.onToggle,
      iconCloseTag = _ref.iconCloseTag,
      isOpen = _ref.isOpen,
      iconClear = _ref.iconClear,
      innerRefInput = _ref.innerRefInput,
      placeholder = _ref.placeholder,
      children = _ref.children,
      onInputKeyDown = _ref.onInputKeyDown,
      onChange = _ref.onChange,
      onChangeTags = _ref.onChangeTags,
      onSelect = _ref.onSelect,
      disabled = _ref.disabled,
      required = _ref.required,
      tabIndex = _ref.tabIndex,
      autoComplete = _ref.autoComplete,
      inputMode = _ref.inputMode,
      type = _ref.type;
  var MoleculeInputTagsRef = useRef();

  var handleMultiSelection = function handleMultiSelection(ev, _ref2) {
    var value = _ref2.value;
    var newTags = tags.includes(value) ? tags.filter(function (tag) {
      return tag !== value;
    }) : [].concat(tags, [value]);
    onChangeTags(ev, {
      value: '',
      tags: newTags
    });
    onSelect(ev, {
      value: '',
      tags: newTags
    });
    onToggle(ev, {
      isOpen: false
    });
    refMoleculeAutosuggest.current.focus();
  };

  var handleChangeTags = function handleChangeTags(ev, _ref3) {
    var tags = _ref3.tags,
        value = _ref3.value;
    var isOpen = Boolean(value);
    onChangeTags(ev, {
      tags: tags
    });
    onToggle(ev, {
      isOpen: isOpen
    });
    refMoleculeAutosuggest.current.focus();
  };

  var handleChange = function handleChange(ev, _ref4) {
    var value = _ref4.value;
    var isOpen = Boolean(value);
    onChange(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: isOpen
    });
  };

  var handleClear = function handleClear() {
    onChange(null, {
      value: ''
    });
    onChangeTags(null, {
      tags: []
    });
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(MoleculeInputTagsWithClearUI, {
    id: id,
    onKeyDown: onInputKeyDown,
    ref: MoleculeInputTagsRef,
    tags: tags,
    value: value,
    onClick: onToggle,
    tagsCloseIcon: iconCloseTag,
    onChangeTags: handleChangeTags,
    onChange: handleChange,
    isOpen: isOpen,
    isVisibleClear: tags.length,
    iconClear: iconClear,
    onClickClear: handleClear,
    innerRefInput: innerRefInput,
    placeholder: !tags.length ? placeholder : '',
    noBorder: true,
    disabled: disabled,
    required: required,
    tabIndex: tabIndex,
    autoComplete: autoComplete,
    inputMode: inputMode,
    type: type
  }), /*#__PURE__*/React.createElement(MoleculeDropdownList, {
    checkbox: true,
    visible: isOpen,
    onSelect: handleMultiSelection,
    value: tags,
    highlightQuery: value
  }, children));
};

MoleculeAutosuggestFieldMultiSelection.displayName = 'MoleculeAutosuggestFieldMultiSelection';
MoleculeAutosuggestFieldMultiSelection.defaultProps = {
  disabled: false,
  value: '',
  tags: [],
  iconCloseTag: /*#__PURE__*/React.createElement("span", null),
  autoComplete: 'nope'
};
export default MoleculeAutosuggestFieldMultiSelection;
